pub enum Sum28<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Aa, Ab> {
Show 28 variants
A(A),
B(B),
C(C),
D(D),
E(E),
F(F),
G(G),
H(H),
I(I),
J(J),
K(K),
L(L),
M(M),
N(N),
O(O),
P(P),
Q(Q),
R(R),
S(S),
T(T),
U(U),
V(V),
W(W),
X(X),
Y(Y),
Z(Z),
Aa(Aa),
Ab(Ab),
}Variants
A(A)
B(B)
C(C)
D(D)
E(E)
F(F)
G(G)
H(H)
I(I)
J(J)
K(K)
L(L)
M(M)
N(N)
O(O)
P(P)
Q(Q)
R(R)
S(S)
T(T)
U(U)
V(V)
W(W)
X(X)
Y(Y)
Z(Z)
Aa(Aa)
Ab(Ab)
Implementations
Sourceimpl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Aa, Ab> Sum28<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Aa, Ab>
impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Aa, Ab> Sum28<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Aa, Ab>
pub fn is_a(&self) -> bool
pub fn a(self) -> Option<A>
pub fn is_b(&self) -> bool
pub fn b(self) -> Option<B>
pub fn is_c(&self) -> bool
pub fn c(self) -> Option<C>
pub fn is_d(&self) -> bool
pub fn d(self) -> Option<D>
pub fn is_e(&self) -> bool
pub fn e(self) -> Option<E>
pub fn is_f(&self) -> bool
pub fn f(self) -> Option<F>
pub fn is_g(&self) -> bool
pub fn g(self) -> Option<G>
pub fn is_h(&self) -> bool
pub fn h(self) -> Option<H>
pub fn is_i(&self) -> bool
pub fn i(self) -> Option<I>
pub fn is_j(&self) -> bool
pub fn j(self) -> Option<J>
pub fn is_k(&self) -> bool
pub fn k(self) -> Option<K>
pub fn is_l(&self) -> bool
pub fn l(self) -> Option<L>
pub fn is_m(&self) -> bool
pub fn m(self) -> Option<M>
pub fn is_n(&self) -> bool
pub fn n(self) -> Option<N>
pub fn is_o(&self) -> bool
pub fn o(self) -> Option<O>
pub fn is_p(&self) -> bool
pub fn p(self) -> Option<P>
pub fn is_q(&self) -> bool
pub fn q(self) -> Option<Q>
pub fn is_r(&self) -> bool
pub fn r(self) -> Option<R>
pub fn is_s(&self) -> bool
pub fn s(self) -> Option<S>
pub fn is_t(&self) -> bool
pub fn t(self) -> Option<T>
pub fn is_u(&self) -> bool
pub fn u(self) -> Option<U>
pub fn is_v(&self) -> bool
pub fn v(self) -> Option<V>
pub fn is_w(&self) -> bool
pub fn w(self) -> Option<W>
pub fn is_x(&self) -> bool
pub fn x(self) -> Option<X>
pub fn is_y(&self) -> bool
pub fn y(self) -> Option<Y>
pub fn is_z(&self) -> bool
pub fn z(self) -> Option<Z>
pub fn is_aa(&self) -> bool
pub fn aa(self) -> Option<Aa>
pub fn is_ab(&self) -> bool
pub fn ab(self) -> Option<Ab>
pub fn as_ref( &self, ) -> Sum28<&A, &B, &C, &D, &E, &F, &G, &H, &I, &J, &K, &L, &M, &N, &O, &P, &Q, &R, &S, &T, &U, &V, &W, &X, &Y, &Z, &Aa, &Ab> ⓘ
pub fn as_mut( &mut self, ) -> Sum28<&mut A, &mut B, &mut C, &mut D, &mut E, &mut F, &mut G, &mut H, &mut I, &mut J, &mut K, &mut L, &mut M, &mut N, &mut O, &mut P, &mut Q, &mut R, &mut S, &mut T, &mut U, &mut V, &mut W, &mut X, &mut Y, &mut Z, &mut Aa, &mut Ab> ⓘ
pub fn as_pin_ref<'a>( self: Pin<&'a Self>, ) -> Sum28<Pin<&'a A>, Pin<&'a B>, Pin<&'a C>, Pin<&'a D>, Pin<&'a E>, Pin<&'a F>, Pin<&'a G>, Pin<&'a H>, Pin<&'a I>, Pin<&'a J>, Pin<&'a K>, Pin<&'a L>, Pin<&'a M>, Pin<&'a N>, Pin<&'a O>, Pin<&'a P>, Pin<&'a Q>, Pin<&'a R>, Pin<&'a S>, Pin<&'a T>, Pin<&'a U>, Pin<&'a V>, Pin<&'a W>, Pin<&'a X>, Pin<&'a Y>, Pin<&'a Z>, Pin<&'a Aa>, Pin<&'a Ab>> ⓘ
pub fn as_pin_mut<'a>( self: Pin<&'a mut Self>, ) -> Sum28<Pin<&'a mut A>, Pin<&'a mut B>, Pin<&'a mut C>, Pin<&'a mut D>, Pin<&'a mut E>, Pin<&'a mut F>, Pin<&'a mut G>, Pin<&'a mut H>, Pin<&'a mut I>, Pin<&'a mut J>, Pin<&'a mut K>, Pin<&'a mut L>, Pin<&'a mut M>, Pin<&'a mut N>, Pin<&'a mut O>, Pin<&'a mut P>, Pin<&'a mut Q>, Pin<&'a mut R>, Pin<&'a mut S>, Pin<&'a mut T>, Pin<&'a mut U>, Pin<&'a mut V>, Pin<&'a mut W>, Pin<&'a mut X>, Pin<&'a mut Y>, Pin<&'a mut Z>, Pin<&'a mut Aa>, Pin<&'a mut Ab>> ⓘ
Sourceimpl<A> Sum28<A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A>
impl<A> Sum28<A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A, A>
pub fn into_inner(self) -> A